package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallMemberCollectSchool;
import com.ruoyi.mall.domain.Vo.MallMemberCollectSchoolVo;
import org.apache.ibatis.annotations.Param;

/**
 * 用户学校收藏Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-26
 */
public interface MallMemberCollectSchoolMapper
{
    /**
     * 查询 我的-收藏学校列表
     * @param mallMemberCollectSchool 用户学校收藏
     * @return 用户学校收藏集合 包含学校详情
     */
    List<MallMemberCollectSchoolVo> selectVoForMineList(MallMemberCollectSchool mallMemberCollectSchool);
    /**
     * 查询用户学校收藏
     *
     * @param collectSchoolId 用户学校收藏主键
     * @return 用户学校收藏
     */
    public MallMemberCollectSchool selectMallMemberCollectSchoolByCollectSchoolId(Long collectSchoolId);

    /**
     * 查询用户收藏学校记录
     * @param schoolId 学校id
     * @param id 用户id
     * @param batchId 批次id
     * @return 结果
     */
    public MallMemberCollectSchool selectCollectByIdAndSchoolId(@Param("schoolId") Long schoolId,
                                                                @Param("id")Long id,
                                                                @Param("batchId")Long batchId);

    /**
     * 查询用户学校收藏列表
     *
     * @param mallMemberCollectSchool 用户学校收藏
     * @return 用户学校收藏集合
     */
    public List<MallMemberCollectSchool> selectMallMemberCollectSchoolList(MallMemberCollectSchool mallMemberCollectSchool);

    /**
     * 新增用户学校收藏
     *
     * @param mallMemberCollectSchool 用户学校收藏
     * @return 结果
     */
    public int insertMallMemberCollectSchool(MallMemberCollectSchool mallMemberCollectSchool);

    /**
     * 修改用户学校收藏
     *
     * @param mallMemberCollectSchool 用户学校收藏
     * @return 结果
     */
    public int updateMallMemberCollectSchool(MallMemberCollectSchool mallMemberCollectSchool);

    /**
     * 删除用户学校收藏
     *
     * @param collectSchoolId 用户学校收藏主键
     * @return 结果
     */
    public int deleteMallMemberCollectSchoolByCollectSchoolId(Long collectSchoolId);

    /**
     * 批量删除用户学校收藏
     *
     * @param collectSchoolIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallMemberCollectSchoolByCollectSchoolIds(Long[] collectSchoolIds);
}
