package com.ruoyi.mall.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallMemberCollectSchool;
import com.ruoyi.mall.service.IMallMemberCollectSchoolService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户学校收藏Controller
 * 
 * @author ruoyi
 * @date 2023-10-26
 */
@RestController
@RequestMapping("/mall/memberCollectSchool")
public class MallMemberCollectSchoolController extends BaseController
{
    @Autowired
    private IMallMemberCollectSchoolService mallMemberCollectSchoolService;

    /**
     * 查询用户学校收藏列表
     */
    @PreAuthorize("@ss.hasPermi('mall:memberCollectSchool:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallMemberCollectSchool mallMemberCollectSchool)
    {
        startPage();
        List<MallMemberCollectSchool> list = mallMemberCollectSchoolService.selectMallMemberCollectSchoolList(mallMemberCollectSchool);
        return getDataTable(list);
    }

    /**
     * 导出用户学校收藏列表
     */
    @PreAuthorize("@ss.hasPermi('mall:memberCollectSchool:export')")
    @Log(title = "用户学校收藏", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MallMemberCollectSchool mallMemberCollectSchool)
    {
        List<MallMemberCollectSchool> list = mallMemberCollectSchoolService.selectMallMemberCollectSchoolList(mallMemberCollectSchool);
        ExcelUtil<MallMemberCollectSchool> util = new ExcelUtil<MallMemberCollectSchool>(MallMemberCollectSchool.class);
        util.exportExcel(response, list, "用户学校收藏数据");
    }

    /**
     * 获取用户学校收藏详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:memberCollectSchool:query')")
    @GetMapping(value = "/{collectSchoolId}")
    public AjaxResult getInfo(@PathVariable("collectSchoolId") Long collectSchoolId)
    {
        return AjaxResult.success(mallMemberCollectSchoolService.selectMallMemberCollectSchoolByCollectSchoolId(collectSchoolId));
    }

    /**
     * 新增用户学校收藏
     */
    @PreAuthorize("@ss.hasPermi('mall:memberCollectSchool:add')")
    @Log(title = "用户学校收藏", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallMemberCollectSchool mallMemberCollectSchool)
    {
        return toAjax(mallMemberCollectSchoolService.insertMallMemberCollectSchool(mallMemberCollectSchool));
    }

    /**
     * 修改用户学校收藏
     */
    @PreAuthorize("@ss.hasPermi('mall:memberCollectSchool:edit')")
    @Log(title = "用户学校收藏", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallMemberCollectSchool mallMemberCollectSchool)
    {
        return toAjax(mallMemberCollectSchoolService.updateMallMemberCollectSchool(mallMemberCollectSchool));
    }

    /**
     * 删除用户学校收藏
     */
    @PreAuthorize("@ss.hasPermi('mall:memberCollectSchool:remove')")
    @Log(title = "用户学校收藏", businessType = BusinessType.DELETE)
	@DeleteMapping("/{collectSchoolIds}")
    public AjaxResult remove(@PathVariable Long[] collectSchoolIds)
    {
        return toAjax(mallMemberCollectSchoolService.deleteMallMemberCollectSchoolByCollectSchoolIds(collectSchoolIds));
    }
}
